@@ -1,6 +1,7 @@
 # from acclimatise.flag_parser.elements import cli_id, any_flag, long_flag, short_flag, flag_with
 from pathlib import Path
 
+from acclimatise.flag_parser.elements import customIndentedBlock
 from acclimatise.usage_parser.model import UsageElement
 
 from .elements import *
@@ -15,8 +16,8 @@ def normalise_cline(tokens):
     return [Path(el.lower()).stem for el in tokens]
 
 
-def parse_usage(cmd, text):
-    toks = usage.searchString(text)
+def parse_usage(cmd, text, debug=False) -> Command:
+    toks = usage.setDebug(debug).searchString(text)
     if not toks:
         # If we had no results, return an empty command
         return Command(command=cmd, positional=[], named=[])
@@ -27,7 +28,7 @@ def parse_usage(cmd, text):
     flags = [tok for tok in toks if isinstance(tok, Flag)]
 
     # Remove an "options" argument which is just a proxy for other flags
-    positional = [pos for pos in positional if pos.text.lower() != "options"]
+    # positional = [pos for pos in positional if pos.text.lower() != "options"]
     # The usage often starts with a re-iteration of the command name itself. Remove this if present
     for i in range(len(positional)):
         # For each positional argument, if the entire cmd string is present, slice away this and everything before it
